/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.engine.script;

import java.io.File;
import java.util.List;

import org.objectweb.petals.component.framework.PEtALSCFException;
import org.objectweb.petals.component.framework.su.ServiceUnitListener;
import org.objectweb.petals.component.framework.util.Extensions;
import org.objectweb.petals.jbi.descriptor.JBIDescriptor;
import org.objectweb.petals.jbi.descriptor.Provides;

/**
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 * 
 */
public class ScriptSUListener implements ServiceUnitListener {

    private ScriptContext context;

    /**
     * Creates a new instance of {@link ScriptSUListener}
     * 
     */
    public ScriptSUListener(ScriptContext context) {
        this.context = context;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.su.ServiceUnitListener#onSUDeployed(java.lang.String,
     *      java.lang.String, org.objectweb.petals.jbi.descriptor.JBIDescriptor)
     */
    public void onSUDeployed(String serviceUnitName, String suRootPath,
            JBIDescriptor descriptor) throws PEtALSCFException {

        // get the script from the SU
        List<Provides> list = descriptor.getServices().getProvides();
        for (Provides provides : list) {
            Extensions extensions = new Extensions(provides.getExtensions());
            String scriptName = extensions.getValue("script");
            File scriptFile = new File(suRootPath, scriptName);
            if (scriptFile.exists()) {
                JBIScript script = context.loadScriptInstance(scriptFile);
                if (script != null) {
                    context.addScriptInstance(provides.toString(), script);
                }
            }
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.su.ServiceUnitListener#onSUStarted(java.lang.String)
     */
    public void onSUStarted(String serviceUnitName) throws PEtALSCFException {
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.su.ServiceUnitListener#onSUStopped(java.lang.String)
     */
    public void onSUStopped(String serviceUnitName) throws PEtALSCFException {
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.objectweb.petals.component.framework.su.ServiceUnitListener#onSUUndeployed(java.lang.String,
     *      java.lang.String, org.objectweb.petals.jbi.descriptor.JBIDescriptor)
     */
    public void onSUUndeployed(String serviceUnitName, String suRootPath,
            JBIDescriptor descriptor) throws PEtALSCFException {
    }

}
